==> component-data-table-4.0.2.tgz: package/src/MoveRowButtons.tsx <==
import React from 'react';
import { Icon } from '@cloudflare/component-icon';
import { Div } from '@cloudflare/elements';
import { Button, ButtonGroup } from '@cloudflare/component-button';
import { useI18n } from '@cloudflare/intl-react';

const ICON_SIZE = 16;
type Props = {
  describedBy: string[];
  handleMoveUpClick?: () => void;
  handleMoveDownClick?: () => void;
};
const MoveRowButtons = ({
  describedBy = [],
  handleMoveUpClick,
  handleMoveDownClick
}: Props) => {
  const { t } = useI18n();
  const ariaDescribedBy = describedBy.join(' ');
  return (
    <ButtonGroup>
      <Button
        px={1}
        py={1}
        aria-describedby={ariaDescribedBy}
        ariaLabel={t('common.table.move_up')}
        disabled={handleMoveUpClick === undefined}
        onClick={handleMoveUpClick}
      >
        <Div
          transform="rotate(90deg)"
          display="inline-block"
          width={ICON_SIZE}
          height={ICON_SIZE}
        >
          <Icon type="backward" label={false} />
        </Div>
      </Button>
      <Button
        px={1}
        py={1}
        ml="1px"
        aria-describedby={ariaDescribedBy}
        ariaLabel={t('common.table.move_down')}
        disabled={handleMoveDownClick === undefined}
        onClick={handleMoveDownClick}
      >
        <Div
          transform="rotate(90deg)"
          display="inline-block"
          width={ICON_SIZE}
          height={ICON_SIZE}
        >
          <Icon type="forward" label={false} />
        </Div>
      </Button>
    </ButtonGroup>
  );
};
export default MoveRowButtons;

==> component-data-table-6.0.42.tgz: package/src/MoveRowButtons.tsx <==
import React from 'react';
import { Icon } from '@cloudflare/component-icon';
import { Div } from '@cloudflare/elements';
import { Button, ButtonGroup } from '@cloudflare/component-button';
import { useI18n } from '@cloudflare/intl-react';

const ICON_SIZE = 16;
type Props = {
  describedBy: string[];
  handleMoveUpClick?: () => void;
  handleMoveDownClick?: () => void;
};
const MoveRowButtons = ({
  describedBy = [],
  handleMoveUpClick,
  handleMoveDownClick
}: Props) => {
  const { t } = useI18n();
  const ariaDescribedBy = describedBy.join(' ');
  return (
    <ButtonGroup>
      <Button
        px={1}
        py={1}
        aria-describedby={ariaDescribedBy}
        ariaLabel={t('common.table.move_up')}
        disabled={handleMoveUpClick === undefined}
        onClick={handleMoveUpClick}
      >
        <Div
          transform="rotate(90deg)"
          display="inline-block"
          width={ICON_SIZE}
          height={ICON_SIZE}
        >
          <Icon type="backward" />
        </Div>
      </Button>
      <Button
        px={1}
        py={1}
        ml="1px"
        aria-describedby={ariaDescribedBy}
        ariaLabel={t('common.table.move_down')}
        disabled={handleMoveDownClick === undefined}
        onClick={handleMoveDownClick}
      >
        <Div
          transform="rotate(90deg)"
          display="inline-block"
          width={ICON_SIZE}
          height={ICON_SIZE}
        >
          <Icon type="forward" />
        </Div>
      </Button>
    </ButtonGroup>
  );
};
export default MoveRowButtons;
